==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-admin/lxqt-admin-user/lxqt-admin-user_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT" sourcelanguage="it_IT">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Impostazioni gruppi</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome del gruppo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>ID gruppo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>Utenti appartenenti al gruppo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <location filename="../groupdialog.cpp" line="92"/>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <source>The group ID is in use.</source>
        <translation>ID di gruppo già in uso.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="92"/>
        <source>The group name cannot be empty.</source>
        <translation>Il nome del gruppo non può essere vuoto.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>The group name is in use.</source>
        <translation>Il nome del gruppo è già in uso.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Impostazioni utenti e gruppi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translatorcomment>remove &amp;_ in source</translatorcomment>
        <translation>&amp;Utenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Nome di accesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>ID utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Cartella Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostra utenti di sistema (solo utenti avanzati)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Gruppi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>ID gruppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Aggiungi nuovi utenti o gruppi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Elimina l&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>modifica le proprietà dell&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Aggiorna l&apos;elenco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Si è sicuro di voler eliminare l&apos;utente selezionato?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Si è sicuro di voler eliminare il gruppo selezionato?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Impostazioni utente</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Nome di accesso:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Imposta la password:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>ID utente:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Gruppo principale:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Shell di login:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Cartella Home:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="64"/>
        <source>Change password:</source>
        <translation>Cambia password:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <location filename="../userdialog.cpp" line="138"/>
        <location filename="../userdialog.cpp" line="143"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <source>The user ID is in use.</source>
        <translation>ID utente già in uso.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="138"/>
        <source>The user name cannot be empty.</source>
        <translation>Il nome non può essere vuoto.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="143"/>
        <source>The user name is in use.</source>
        <translation>Il nome utente è già in uso.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Si è sicuro di voler utilizzare una password vuota per l&apos;utente?</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-admin/lxqt-admin-user/lxqt-admin-user_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT" sourcelanguage="it_IT">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Impostazioni gruppi</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome del gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>ID gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>Utenti appartenenti al gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <source>The group ID is in use.</source>
        <translation>ID di gruppo già in uso.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <source>The group name cannot be empty.</source>
        <translation>Il nome del gruppo non può essere vuoto.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>The group name is in use.</source>
        <translation>Il nome del gruppo è già in uso.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Impostazioni utenti e gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translatorcomment>remove &amp;_ in source</translatorcomment>
        <translation>&amp;Utenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Nome di accesso</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>ID utente</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Cartella Home</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostra utenti di sistema (solo utenti avanzati)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>ID gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Aggiungi nuovi utenti o gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Elimina l&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>modifica le proprietà dell&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Aggiorna l&apos;elenco</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Si è sicuro di voler eliminare l&apos;utente selezionato?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Si è sicuro di voler eliminare il gruppo selezionato?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Impostazioni utente</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Nome di accesso:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Imposta la password:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>ID utente:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Gruppo principale:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Shell di login:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Cartella Home:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="67"/>
        <source>Change password:</source>
        <translation>Cambia password:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <location filename="../../../userdialog.cpp" line="141"/>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <source>The user ID is in use.</source>
        <translation>ID utente già in uso.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="141"/>
        <source>The user name cannot be empty.</source>
        <translation>Il nome non può essere vuoto.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>The user name is in use.</source>
        <translation>Il nome utente è già in uso.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Si è sicuro di voler utilizzare una password vuota per l&apos;utente?</translation>
    </message>
</context>
</TS>
